OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Das Schreiben in das „config“-Verzeichnis ist nicht möglich!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Dies kann normalerweise repariert werden, indem dem Webserver Schreibzugriff auf das config-Verzeichnis gegeben wird",
    "See %s" : "Siehe %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Dies kann normalerweise behoben werden, %sindem dem Webserver Schreibzugriff auf das Konfigurationsverzeichnis gegeben wird%s.",
    "Sample configuration detected" : "Beispielkonfiguration gefunden",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Es wurde festgestellt, dass die Beispielkonfiguration kopiert wurde. Dies kann Deine Installation zerstören und wird nicht unterstützt. Bitte lies die Dokumentation, bevor Du Änderungen an der config.php vornimmst.",
    "PHP %s or higher is required." : "PHP %s oder höher wird benötigt.",
    "PHP with a version lower than %s is required." : "PHP wird in einer früheren Version als %s benötigt.",
    "%sbit or higher PHP required." : "%sbit oder höheres PHP wird benötigt.",
    "Following databases are supported: %s" : "Die folgenden Datenbanken werden unterstützt: %s",
    "The command line tool %s could not be found" : "Das Kommandozeilenwerkzeug %s konnte nicht gefunden werden",
    "The library %s is not available." : "Die Bibliothek %s ist nicht verfügbar.",
    "Library %s with a version higher than %s is required - available version %s." : "Die Bibliothek %s wird in einer neueren Version als %s benötigt - verfügbare Version ist %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Die Bibliothek %s wird in einer früheren Version als %s benötigt - verfügbare Version ist %s.",
    "Following platforms are supported: %s" : "Die folgenden Plattformen werden unterstützt: %s",
    "ownCloud %s or higher is required." : "ownCloud %s oder höher wird benötigt.",
    "ownCloud %s or lower is required." : "ownCloud %s oder niedriger wird benötigt.",
    "Unknown filetype" : "Unbekannter Dateityp",
    "Invalid image" : "Ungültiges Bild",
    "Avatar image is not square" : "Avatar-Bild ist nicht quadratisch",
    "today" : "Heute",
    "yesterday" : "Gestern",
    "_%n day ago_::_%n days ago_" : ["Vor %n Tag","Vor %n Tagen"],
    "last month" : "Letzten Monat",
    "_%n month ago_::_%n months ago_" : ["Vor %n Monat","Vor %n Monaten"],
    "last year" : "Letztes Jahr",
    "_%n year ago_::_%n years ago_" : ["Vor %n Jahr","Vor %n Jahren"],
    "_%n hour ago_::_%n hours ago_" : ["Vor %n Stunde","Vor %n Stunden"],
    "_%n minute ago_::_%n minutes ago_" : ["Vor %n Minute","Vor %n Minuten"],
    "seconds ago" : "Gerade eben",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Das Modul mit der ID: %s existiert nicht. Bitte aktiviere es in Deinen App-Einstellungen oder kontaktiere Deinen Administrator.",
    "Builtin" : "eingebaut",
    "None" : "Keine",
    "Username and password" : "Benutzername und Passwort",
    "Username" : "Benutzername",
    "Password" : "Passwort",
    "Log-in credentials, save in session" : "Anmeldedaten in Sitzung speichern",
    "Empty filename is not allowed" : "Ein leerer Dateiname ist nicht erlaubt",
    "Dot files are not allowed" : "Dateinamen mit einem Punkt am Anfang sind nicht erlaubt",
    "4-byte characters are not supported in file names" : "4-Byte Zeichen sind in Dateinamen nicht erlaubt",
    "File name is a reserved word" : "Der Dateiname ist ein reserviertes Wort",
    "File name contains at least one invalid character" : "Der Dateiname enthält mindestens ein ungültiges Zeichen",
    "File name is too long" : "Dateiname ist zu lang",
    "App directory already exists" : "Das Applikationsverzeichnis existiert bereits",
    "Can't create app folder. Please fix permissions. %s" : "Es kann kein Applikationsordner erstellt werden. Bitte passe die  Berechtigungen an. %s",
    "Archive does not contain a directory named %s" : "Das Archiv enthält kein Verzeichnis mit dem Namen %s",
    "No source specified when installing app" : "Für die Installation der Applikation wurde keine Quelle angegeben",
    "No href specified when installing app from http" : "Für die Installation der Applikation über http wurde keine Quelle (href) angegeben",
    "No path specified when installing app from local file" : "Bei der Installation der Applikation aus einer lokalen Datei wurde kein Pfad angegeben",
    "Archives of type %s are not supported" : "Archive vom Typ %s werden nicht unterstützt",
    "Failed to open archive when installing app" : "Das Archiv konnte bei der Installation der Applikation nicht geöffnet werden",
    "App does not provide an info.xml file" : "Die Applikation enthält keine info.xml Datei",
    "App cannot be installed because appinfo file cannot be read." : "Die Anwendung kann nicht installiert werden, weil die Anwendungsinfodatei nicht gelesen werden kann.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Die Signatur konnte nicht überprüft werden. Bitte kontaktiere  die App-Entwickler und überprüfe deinen Admin-Bildschirm.",
    "App can't be installed because of not allowed code in the App" : "Die App kann nicht installiert werden, weil sie unerlaubten Code enthält",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Die App kann nicht installiert werden, weil sie mit dieser Version von ownCloud nicht kompatibel ist",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Die App kann nicht installiert werden, weil sie den <shipped>true</shipped>-Tag enthält, der bei Apps, die nicht zum Standardumfang von ownCloud gehören, nicht erlaubt ist",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Diese App kann nicht installiert werden, da die Version in info.xml nicht die gleiche Version wie die aus dem App Store ist.",
    "Apps" : "Apps",
    "General" : "Allgemein",
    "Storage" : "Speicher",
    "Security" : "Sicherheit",
    "User Authentication" : "Nutzer-Authentifizierung",
    "Encryption" : "Verschlüsselung",
    "Workflows & Tags" : "Arbeitsabläufe & Tags",
    "Sharing" : "Teilen",
    "Search" : "Suche",
    "Updates" : "Updates",
    "Help & Tips" : "Hilfe & Tipps",
    "Additional" : "Zusätzlich",
    "%s enter the database username and name." : "%s bitte gib den Datenbank Benutzernamen und den Datenbank Namen ein.",
    "%s enter the database username." : "%s gib den Datenbank-Benutzernamen an.",
    "%s enter the database name." : "%s gib den Datenbanknamen an.",
    "%s you may not use dots in the database name" : "%s Der Datenbankname darf keine Punkte enthalten",
    "Oracle connection could not be established" : "Es konnte keine Verbindung zur Oracle-Datenbank hergestellt werden",
    "Oracle username and/or password not valid" : "Oracle-Benutzername und/oder -Passwort ungültig",
    "DB Error: \"%s\"" : "DB-Fehler: „%s“",
    "Offending command was: \"%s\"" : "Fehlerhafter Befehl war: „%s“",
    "You need to enter either an existing account or the administrator." : "Du musst entweder ein existierendes Benutzerkonto oder das Administratorenkonto angeben.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Fehlerhafter Befehl war: „%s“, Name: %s, Passwort: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL-Benutzername und/oder -Passwort ungültig",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X wird nicht unterstützt und %s wird auf dieser Plattform nicht richtig funktionieren. Die Benutzung erfolgt auf eigene Gefahr!",
    "For the best results, please consider using a GNU/Linux server instead." : "Zur Gewährleistung eines optimalen Betriebs sollte stattdessen ein GNU/Linux-Server verwendet werden.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Es scheint, dass diese %s-Instanz unter einer 32-Bit-PHP-Umgebung läuft und open_basedir in der Datei php.ini konfiguriert worden ist. Von einem solchen Betrieb wird dringend abgeraten, weil es dabei zu Problemen mit Dateien kommt, deren Größe 4 GB übersteigt.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bitte entferne die open_basedir-Einstellung in Deiner php.ini oder wechsele zu 64-Bit-PHP.",
    "Set an admin username." : "Einen Administrator-Benutzernamen setzen.",
    "Set an admin password." : "Ein Administrator-Passwort setzen.",
    "Can't create or write into the data directory %s" : "Das Datenverzeichnis %s kann nicht erstellt oder es kann darin nicht geschrieben werden.",
    "Invalid Federated Cloud ID" : "Ungültige Federated-Cloud-ID",
    "%s shared »%s« with you" : "%s hat „%s“ mit Dir geteilt",
    "%s via %s" : "%s via %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Freigabe von %s fehlgeschlagen, da das Backend die Freigabe vom Typ %i nicht erlaubt.",
    "Sharing %s failed, because the file does not exist" : "Freigabe von %s fehlgeschlagen, da die Datei nicht existiert",
    "You are not allowed to share %s" : "Die Freigabe von %s ist Dir nicht erlaubt",
    "Sharing %s failed, because you can not share with yourself" : "Freigabe von %s fehlgeschlagen, da du nichts mit dir selbst teilen kannst",
    "Sharing %s failed, because the user %s does not exist" : "Freigabe von %s fehlgeschlagen, da der Nutzer %s nicht existiert",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Freigabe von %s fehlgeschlagen, da der Nutzer %s kein Gruppenmitglied einer der Gruppen von %s ist",
    "Sharing %s failed, because this item is already shared with %s" : "Freigabe von %s fehlgeschlagen, da dieses Objekt schon mit %s geteilt wird",
    "Sharing %s failed, because this item is already shared with user %s" : "Freigabe von %s fehlgeschlagen, da dieses Objekt schon mit Nutzer %s geteilt wird",
    "Sharing %s failed, because the group %s does not exist" : "Freigabe von %s fehlgeschlagen, da die Gruppe %s nicht existiert",
    "Sharing %s failed, because %s is not a member of the group %s" : "Freigabe von %s fehlgeschlagen, da %s kein Mitglied der Gruppe %s ist",
    "You need to provide a password to create a public link, only protected links are allowed" : "Es sind nur geschützte Links zulässig, daher müssen Sie ein Passwort angeben, um einen öffentlichen Link zu generieren",
    "Sharing %s failed, because sharing with links is not allowed" : "Freigabe von %s fehlgeschlagen, da das Teilen von Verknüpfungen nicht erlaubt ist",
    "Not allowed to create a federated share with the same user" : "Das Erstellen einer Federated Cloud Freigabe mit dem gleichen Benutzer ist nicht erlaubt",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Freigabe von %s fehlgeschlagen, da %s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar.",
    "Share type %s is not valid for %s" : "Freigabetyp %s ist nicht gültig für %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Das Setzen der Berechtigungen für %s ist fehlgeschlagen, da die Berechtigungen, die erteilten Berechtigungen %s überschreiten",
    "Setting permissions for %s failed, because the item was not found" : "Das Setzen der Berechtigungen für %s ist fehlgeschlagen, da das Objekt nicht gefunden wurde",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Ablaufdatum kann nicht gesetzt werden. Freigaben können nach dem Teilen, nicht länger als %s gültig sein.",
    "Cannot set expiration date. Expiration date is in the past" : "Ablaufdatum kann nicht gesetzt werden. Ablaufdatum liegt in der Vergangenheit.",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Ablaufdatum kann nicht gelöscht werden. Freigaben werden für ein Ablaufdatum benötigt.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Freigabe-Backend %s muss in der OCP\\Share_Backend - Schnittstelle implementiert werden",
    "Sharing backend %s not found" : "Freigabe-Backend %s nicht gefunden",
    "Sharing backend for %s not found" : "Freigabe-Backend für %s nicht gefunden",
    "Sharing failed, because the user %s is the original sharer" : "Freigabe fehlgeschlagen, da der Nutzer %s der offizielle Freigeber ist",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Freigabe von %s fehlgeschlagen, da die Berechtigungen die erteilten Berechtigungen %s überschreiten",
    "Sharing %s failed, because resharing is not allowed" : "Freigabe von %s fehlgeschlagen, da das nochmalige Freigeben einer Freigabe nicht erlaubt ist",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Freigabe von %s fehlgeschlagen, da das Freigabe-Backend für %s nicht in dieser Quelle gefunden werden konnte",
    "Sharing %s failed, because the file could not be found in the file cache" : "Freigabe von %s fehlgeschlagen, da die Datei im Datei-Cache nicht gefunden werden konnte",
    "Cannot increase permissions of %s" : "Kann die Berechtigungen von %s nicht erhöhen",
    "Files can't be shared with delete permissions" : "Dateien mit Lösch-Berechtigungen können nicht geteilt werden",
    "Files can't be shared with create permissions" : "Dateien mit Erstell-Berechtigungen können nicht geteilt werden",
    "Expiration date is in the past" : "Ablaufdatum ist in der Vergangenheit",
    "Cannot set expiration date more than %s days in the future" : "Das Ablaufdatum kann nicht mehr als %s Tage in die Zukunft liegen",
    "Could not find category \"%s\"" : "Die Kategorie „%s“ konnte nicht gefunden werden",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Folgende Zeichen sind im Benutzernamen erlaubt: „a-z“, „A-Z“, „0-9“ und „_.@-'“",
    "A valid username must be provided" : "Es muss ein gültiger Benutzername angegeben werden",
    "Username contains whitespace at the beginning or at the end" : "Der Benutzername enthält Leerzeichen am Anfang oder am Ende",
    "A valid password must be provided" : "Es muss ein gültiges Passwort angegeben werden",
    "The username is already being used" : "Dieser Benutzername existiert bereits",
    "Login canceled by app" : "Anmeldung durch die App abgebrochen",
    "User disabled" : "Nutzer deaktiviert",
    "Help" : "Hilfe",
    "Settings" : "Einstellungen",
    "Users" : "Benutzer",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Die App „%s“ kann nicht installiert werden, da die folgenden Abhängigkeiten nicht erfüllt sind: %s",
    "web services under your control" : "Web-Dienste unter Deiner Kontrolle",
    "File is currently busy, please try again later" : "Die Datei ist zur Zeit in Benutzung, bitte versuche es später noch einmal",
    "Can't read file" : "Datei kann nicht gelesen werden",
    "Application is not enabled" : "Die App ist nicht aktiviert",
    "Authentication error" : "Authentifizierungsfehler",
    "Token expired. Please reload page." : "Token abgelaufen. Bitte lade die Seite neu.",
    "Unknown user" : "Unbekannter Benutzer",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Keine Datenbanktreiber (SQLite, MySQL oder PostgreSQL) installiert.",
    "Cannot write into \"config\" directory" : "Das Schreiben in das „config“-Verzeichnis ist nicht möglich",
    "Cannot write into \"apps\" directory" : "Das Schreiben in das „apps“-Verzeichnis ist nicht möglich",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Dies kann normalerweise behoben werden, %sindem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird%s oder der App Store in der Konfigurationsdatei deaktiviert wird.",
    "Cannot create \"data\" directory" : "Das Erstellen des „data“-Verzeichnisses ist nicht möglich",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Dies kann normalerweise repariert werden, indem dem Webserver <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> Schreibzugriff auf das Wurzelverzeichnis gegeben wird</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Berechtigungen können normalerweise repariert werden, indem dem Webserver %s Schreibzugriff auf das Wurzelverzeichnis %s gegeben wird.",
    "Setting locale to %s failed" : "Das Setzen der Umgebungslokale auf %s fehlgeschlagen",
    "Please install one of these locales on your system and restart your webserver." : "Bitte installiere eine dieser Sprachen auf Deinem System und starte den Webserver neu.",
    "Please ask your server administrator to install the module." : "Bitte frage, für die Installation des Moduls, Deinen Server-Administrator.",
    "PHP module %s not installed." : "PHP-Modul %s nicht installiert.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-Einstellung „%s“ ist nicht auf „%s“ gesetzt.",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Durch das Anpassen dieser Einstellung in der php.ini wird ownCloud wieder laufen",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload ist nicht auf den erwarteten Wert „0“, sondern stattdessen  auf „%s“ gesetzt",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Bitte setze zum Beheben dieses Problems <code>mbstring.func_overload</code> in Deiner php.ini auf <code>0</code>.",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 wird benötigt. Zur Zeit ist %s installiert.",
    "To fix this issue update your libxml2 version and restart your web server." : "Um diesen Fehler zu beheben, aktualisiere bitte die libxml2 Version und starte deinen Browser neu.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ist offenbar so konfiguriert, dass PHPDoc-Blöcke in der Anweisung entfernt werden. Dadurch sind mehrere Kern-Apps nicht erreichbar.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie etwa Zend OPcache oder eAccelerator verursacht.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-Module wurden installiert, werden aber als noch fehlend gelistet?",
    "Please ask your server administrator to restart the web server." : "Bitte kontaktiere Deinen Server-Administrator und bitte um den Neustart des Webservers.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 benötigt",
    "Please upgrade your database version" : "Bitte aktualisiere Deine Datenbankversion",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Bitte ändere die Berechtigungen auf 0770 sodass das Verzeichnis nicht von anderen Nutzer angezeigt werden kann.",
    "Your Data directory is readable by other users" : "Dein Daten-Verzeichnis ist von anderen Benutzern lesbar",
    "Your Data directory must be an absolute path" : "Dein Datenverzeichnis muss ein absoluter Pfad sein",
    "Check the value of \"datadirectory\" in your configuration" : "Überprüfe bitte die Angabe unter „datadirectory“ in Deiner Konfiguration",
    "Your Data directory  is invalid" : "Dein Daten-Verzeichnis ist ungültig",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Bitte stelle sicher, dass das Datenverzeichnis auf seiner ersten Ebene eine Datei namens „.ocdata“ enthält.",
    "Could not obtain lock type %d on \"%s\"." : "Sperrtyp %d auf „%s“ konnte nicht ermittelt werden.",
    "Storage unauthorized. %s" : "Speichern nicht erlaubt. %s",
    "Storage incomplete configuration. %s" : "Unvollständige Konfiguration des Storage. %s",
    "Storage connection error. %s" : "Verbindungsfehler zum Storage. %s",
    "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
    "Storage connection timeout. %s" : "Zeitüberschreitung der Verbindung zum Storage. %s",
    "A safe home for all your data" : "Ein sicherer Speicherplatz für deine ganzen Daten.",
    "The username must be at least 3 characters long" : "Der Nutzername muss mindestens 3 Zeichen lang sein",
    "File cannot be read" : "Datei kann nicht gelesen werden",
    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s wird nicht unterstützt und %s wird auf dieser Plattform nicht ordnungsgemäß funktionieren. Benutzung auf eigene Gefahr!",
    "Sharing %s failed, could not find %s, check spelling and server availability." : "Das Teilen von %s schlug fehl, konnte %s nicht finden, prüfen Sie die Schreibweise und Serververfügbarkeit.",
    "Imprint" : "Impressum",
    "The username can not be longer than 64 characters" : "Der Benutzername darf nicht länger als 64 Zeichen sein",
    "Privacy Policy" : "Datenschutzerklärung",
    "__language_name__" : "Deutsch (Persönlich)"
},
"nplurals=2; plural=(n != 1);");
